@@ -78,6 +78,12 @@ then
     export VIRTUALENVWRAPPER_PROJECT_FILENAME=".project"
 fi
 
+# Remember where we are running from.
+if [ -z "$VIRTUALENVWRAPPER_SCRIPT" ]
+then
+    export VIRTUALENVWRAPPER_SCRIPT="$0"
+fi
+
 # Portable shell scripting is hard, let's go shopping.
 #
 # People insist on aliasing commands like 'cd', either with a real
@@ -229,7 +235,7 @@ function virtualenvwrapper_run_hook {
 virtualenvwrapper.sh: There was a problem running the initialization hooks. 
 
 If Python could not import the module virtualenvwrapper.hook_loader,
-check that virtualenv has been installed for
+check that virtualenvwrapper has been installed for
 VIRTUALENVWRAPPER_PYTHON=$VIRTUALENVWRAPPER_PYTHON and that PATH is
 set properly.
 EOF
@@ -375,6 +381,7 @@ function virtualenvwrapper_mkvirtualenv_help {
 # Usage: mkvirtualenv [options] ENVNAME
 # (where the options are passed directly to virtualenv)
 #
+#:help:mkvirtualenv: Create a new virtualenv in $WORKON_HOME
 function mkvirtualenv {
     typeset -a in_args
     typeset -a out_args
@@ -491,7 +498,7 @@ function mkvirtualenv {
     virtualenvwrapper_run_hook "post_mkvirtualenv"
 }
 
-# Remove an environment, in the WORKON_HOME.
+#:help:rmvirtualenv: Remove a virtualenv
 function rmvirtualenv {
     virtualenvwrapper_verify_workon_home || return 1
     if [ ${#@} = 0 ]
@@ -558,9 +565,7 @@ function _lsvirtualenv_usage {
     echo "  -h -- this help message"
 }
 
-# List virtual environments
-#
-# Usage: lsvirtualenv [-l]
+#:help:lsvirtualenv: list virtualenvs
 function lsvirtualenv {
 
     typeset long_mode=true
@@ -608,9 +613,7 @@ function lsvirtualenv {
     fi
 }
 
-# Show details of a virtualenv
-#
-# Usage: showvirtualenv [env]
+#:help:showvirtualenv: show details of a single virtualenv
 function showvirtualenv {
     typeset env_name="$1"
     if [ -z "$env_name" ]
@@ -646,10 +649,7 @@ function virtualenvwrapper_workon_help {
     echo ""
 }
 
-# List or change working virtual environments
-#
-# Usage: workon [environment_name]
-#
+#:help:workon: list or change working virtualenvs
 function workon {
     in_args=( "$@" )
 
@@ -746,7 +746,7 @@ function virtualenvwrapper_get_python_version {
     # VIRTUALENVWRAPPER_PYTHON because we're trying to determine the
     # version installed there so we can build up the path to the
     # site-packages directory.
-    "$VIRTUAL_ENV/bin/python" -V 2>&1 | cut -f2 -d' ' | cut -f-2 -d.
+    "$VIRTUAL_ENV/$VIRTUALENVWRAPPER_ENV_BIN_DIR/python" -V 2>&1 | cut -f2 -d' ' | cut -f-2 -d.
 }
 
 # Prints the path to the site-packages directory for the current environment.
@@ -765,6 +765,8 @@ function virtualenvwrapper_get_site_packages_dir {
 # "virtualenv_path_extensions.pth" inside the virtualenv's
 # site-packages directory; if this file does not exist, it will be
 # created first.
+#
+#:help:add2virtualenv: add directory to the import path
 function add2virtualenv {
     virtualenvwrapper_verify_workon_home || return 1
     virtualenvwrapper_verify_active_environment || return 1
@@ -829,6 +831,7 @@ function add2virtualenv {
 
 # Does a ``cd`` to the site-packages directory of the currently-active
 # virtualenv.
+#:help:cdsitepackages: change to the site-packages directory
 function cdsitepackages {
     virtualenvwrapper_verify_workon_home || return 1
     virtualenvwrapper_verify_active_environment || return 1
@@ -837,6 +840,7 @@ function cdsitepackages {
 }
 
 # Does a ``cd`` to the root of the currently-active virtualenv.
+#:help:cdvirtualenv: change to the $VIRTUAL_ENV directory
 function cdvirtualenv {
     virtualenvwrapper_verify_workon_home || return 1
     virtualenvwrapper_verify_active_environment || return 1
@@ -845,6 +849,7 @@ function cdvirtualenv {
 
 # Shows the content of the site-packages directory of the currently-active
 # virtualenv
+#:help:lssitepackages: list contents of the site-packages directory
 function lssitepackages {
     virtualenvwrapper_verify_workon_home || return 1
     virtualenvwrapper_verify_active_environment || return 1
@@ -862,6 +867,7 @@ function lssitepackages {
 
 # Toggles the currently-active virtualenv between having and not having
 # access to the global site-packages.
+#:help:toggleglobalsitepackages: turn access to global site-packages on/off
 function toggleglobalsitepackages {
     virtualenvwrapper_verify_workon_home || return 1
     virtualenvwrapper_verify_active_environment || return 1
@@ -875,7 +881,7 @@ function toggleglobalsitepackages {
     fi
 }
 
-# Duplicate the named virtualenv to make a new one.
+#:help:cpvirtualenv: duplicate the named virtualenv to make a new one
 function cpvirtualenv {
     virtualenvwrapper_verify_workon_home || return 1
     virtualenvwrapper_verify_virtualenv_clone || return 1
@@ -968,6 +974,7 @@ function virtualenvwrapper_verify_project_home {
 # Given a virtualenv directory and a project directory,
 # set the virtualenv up to be associated with the
 # project
+#:help:setvirtualenvproject: associate a project directory with a virtualenv
 function setvirtualenvproject {
     typeset venv="$1"
     typeset prj="$2"
@@ -1024,7 +1031,7 @@ function virtualenvwrapper_mkproject_help {
     "$VIRTUALENVWRAPPER_PYTHON" -c 'from virtualenvwrapper.hook_loader import main; main()' -l project.template
 }
 
-# Create a new project directory and its associated virtualenv.
+#:help:mkproject: create a new project directory and its associated virtualenv
 function mkproject {
     typeset -a in_args
     typeset -a out_args
@@ -1109,7 +1116,7 @@ function mkproject {
     virtualenvwrapper_run_hook "project.post_mkproject"
 }
 
-# Change directory to the active project
+#:help:cdproject: change directory to the active project
 function cdproject {
     virtualenvwrapper_verify_workon_home || return 1
     virtualenvwrapper_verify_active_environment || return 1
@@ -1135,6 +1142,7 @@ function cdproject {
 #
 # Originally part of virtualenvwrapper.tmpenv plugin
 #
+#:help:mktmpenv: create a temporary virtualenv
 function mktmpenv {
     typeset tmpenvname
     typeset RC
@@ -1163,7 +1171,7 @@ function mktmpenv {
     echo "This is a temporary environment. It will be deleted when you run 'deactivate'." | tee "$VIRTUAL_ENV/README.tmpenv"
 
     # Update the postdeactivate script
-    cat - >> "$VIRTUAL_ENV/bin/postdeactivate" <<EOF
+    cat - >> "$VIRTUAL_ENV/$VIRTUALENVWRAPPER_ENV_BIN_DIR/postdeactivate" <<EOF
 if [ -f "$VIRTUAL_ENV/README.tmpenv" ]
 then
     echo "Removing temporary environment:" $(basename "$VIRTUAL_ENV")
@@ -1175,6 +1183,7 @@ EOF
 #
 # Remove all installed packages from the env
 #
+#:help:wipeenv: remove all packages installed in the current virtualenv
 function wipeenv {
     virtualenvwrapper_verify_workon_home || return 1
     virtualenvwrapper_verify_active_environment || return 1
@@ -1196,6 +1205,7 @@ function wipeenv {
 #
 # Run a command in each virtualenv
 #
+#:help:allvirtualenv: run a command in all virtualenvs
 function allvirtualenv {
     virtualenvwrapper_verify_workon_home || return 1
     typeset d
@@ -1207,13 +1217,39 @@ function allvirtualenv {
         echo "$d" | sed 's/./=/g'
         # Activate the environment, but not with workon
         # because we don't want to trigger any hooks.
-        (source "$WORKON_HOME/$d/bin/activate";
+        (source "$WORKON_HOME/$d/$VIRTUALENVWRAPPER_ENV_BIN_DIR/activate";
             virtualenvwrapper_cd "$VIRTUAL_ENV";
             "$@")
         echo
     done
 }
 
+#:help:virtualenvwrapper: show this help message
+function virtualenvwrapper {
+	cat <<EOF
+
+virtualenvwrapper is a set of extensions to Ian Bicking's virtualenv
+tool.  The extensions include wrappers for creating and deleting
+virtual environments and otherwise managing your development workflow,
+making it easier to work on more than one project at a time without
+introducing conflicts in their dependencies.
+
+For more information please refer to the documentation:
+
+    http://virtualenvwrapper.readthedocs.org/en/latest/command_ref.html
+
+Commands available:
+
+EOF
+
+    typeset helpmarker="#:help:"
+    cat  "$VIRTUALENVWRAPPER_SCRIPT" \
+        | grep "^$helpmarker" \
+        | sed -e "s/^$helpmarker/  /g" \
+        | sort \
+        | sed -e 's/$/\'$'\n/g'
+}
+
 #
 # Invoke the initialization functions
 #
